==> sleepanalyser_1.0-3.tar.gz: sleepanalyser-1.0/src/opt/SleepAnalyser/main.py <==
#!/usr/bin/env python
###########################################################################
# Name: 	         SleepAnalyser
# Description:	 Analyses your movement during your sleep and tries to set the alarm to a good time
# Copyright:     George Rui_collnelli, george@ruinelli.ch
# Last change:  (check version in data.py)
# Licence:         GPL
###########################################################################

import sys
import os
import random
#from PyQt4 import QtGui, QtCore
import time
from time import strftime
import math
import array
import string

from PyQt4.QtCore import * 
from PyQt4.QtGui import * 

import ConfigParser
import os, os.path

import data

from myFunctions import *

from Ui_StartWindow import *
from Ui_CollectingWindow import *
from Ui_LogWindow import *



  
###########################################################################
# Main function
###########################################################################
def main():
    global app,  StartWindow,  CollectingWindow,  LogWindow  #needed?
    global CollectingWindowGraph
   
    try:
        if(sys.argv[1]=="debug"): 
            print "Enable Debug mode"
            data.debug=1
    except:
        data.debug=0

    #if not on the N900, a acceleration sensor has to be simulated
    uname=os.uname()
    if(uname[1]=="Nokia-N900"): data.demo=0	#runs on real N900 hardware
    else: data.demo=1	#runs on other hardware/OS


    if(data.demo==1):
        print "Runs not on a N900 => Use randomizer for acceleration sensor data"
        data.configfolder=data.devconfigfolder
        data.logfolder=data.devlogfolder


    app = QtGui.QApplication(sys.argv)
    
    
    StartWindow = frmStartWindow()    
    CollectingWindow = frmCollectingWindow()
    LogWindow = frmLogWindow()
    
    
    StartWindow.show()
    

    #get configuration
    print "Configuration file:",  data.configfolder+data.ConfigFile
    config = ConfigParser.SafeConfigParser()
    if os.path.exists(data.configfolder+data.ConfigFile):
        config.read(data.configfolder+data.ConfigFile)
        
        data.sampling = config.getint('main', 'sampling')
        data.sample_smoothing = config.getint('main', 'sample_smoothing')
        data.value_smoothing = config.getint('main', 'value_smoothing')
        data.trigger = config.getint('main', 'trigger')
        print "Configuration loaded ("+data.ConfigFile+")"
    else:
        print data.configfolder+data.ConfigFile + " not existing, using default parameters..."
        config.add_section('main')
        config.set('main', 'sampling', str(data.sampling))
        config.set('main', 'sample_smoothing', str(data.sample_smoothing))      
        config.set('main', 'value_smoothing', str(data.value_smoothing))      
        config.set('main', 'trigger', str(data.trigger))      

        if (not os.path.exists(data.configfolder)):
            print "Create configuration folder: ",  data.configfolder
            os.mkdir(data.configfolder)
        try:
            data.configfile = open(data.configfolder+data.ConfigFile, 'w')
            config.write(data.configfile)
            print "Configuration saved"
        except:
            print "Failed to write configuration file!"


    #faster sampling in demo mode
    if(data.debug==1):
        data.sampling=data.sampling/100
    
    #print usefull data
    print "SW version:", data.version
    print "Sampling intervall:", data.sampling, "ms"
    print "sample_smoothing:", data.sample_smoothing, "x"
    print "value_smoothing:", data.value_smoothing, "x"
    print "=> log intervall:", data.sampling*data.value_smoothing/1000, "s"
    print "Trigger level:", data.trigger


    
    StartWindow.UpdateScreenStart()
    StartWindow.show()



    sys.exit(app.exec_())







###########################################################################
# 
###########################################################################
def TimerLoop():
    global CollectingWindowGraph

    r=GetSensorData()
    if(r==1):
        WriteIntoLogFile()
        ProcessData()
        CollectingWindowGraph.update() #show CollectingWindowGraph    
    
    CollectingWindow.UpdateScreen()

  
  
  
  
###########################################################################
# 
###########################################################################
def ShowCollectingWindow():
    CollectingWindow.show()
    StartWindow.hide()
    StartMeasurement()
    
  
###########################################################################
# 
###########################################################################
def ShowLogWindow():
    global LogWindowGraph
    
    data.logfilename = QFileDialog.getOpenFileName(None,"Open SleepCycle Log File", data.logfolder, "Log Files (*.csv)");
    OpenLogFile()
    ProcessData()
    
    LogWindow.UpdateScreen()

    LogWindow.show()
    StartWindow.hide()
    
    LogWindowGraph = LogWindowCanvas()
    LogWindowGraph.show()





def Zoom():
    if(data.zoom==0): data.zoom=1
    else: data.zoom=0
    ProcessData()
    LogWindow.update()








###########################################################################
# 
###########################################################################
def StartMeasurement():
    global CollectingWindowGraph
    global app
    
    StartLogfile()
    
    #init value
    data.arrayMovementdata[0][0]=int(strftime("%H", time.localtime()))
    data.arrayMovementdata[1][0] =int(strftime("%M", time.localtime()))
    
    print data.arrayMovementdata[0][0],  data.arrayMovementdata[1][0]
    print "----------"
        
    CollectingWindowGraph = CollectingWindowCanvas()
    CollectingWindowGraph.show()

    print "Start timers..."
    app.timer_GetData = QtCore.QTimer()
    QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), TimerLoop)        
    app.timer_GetData.start(data.sampling)
    
    CollectingWindow.UpdateScreenStart()
    



###########################################################################
# 
###########################################################################
def StopMeasurement():
    global app

    print "Stop timers..."
    app.timer_GetData.stop()
    StopLogfile()



   
def RaiseTrigger():   
    data.trigger=data.trigger+1
    if(data.trigger>50): data.trigger=50
    
    ProcessData()
    LogWindowGraph.update() #show logWindowGraph    
    LogWindow.UpdateScreen()
    
   
   
   
def LowerTrigger():   
    data.trigger=data.trigger-1
    if(data.trigger<0): data.trigger=0
    
    ProcessData()
    LogWindowGraph.update() #show logWindowGraph    
    LogWindow.UpdateScreen()
   
   
   
   
def showGraph(self):
#        print "--"
        paint = QtGui.QPainter()
        paint.begin(self)

        paint.setFont(QtGui.QFont('Decorative', 12))
        
        #color = QtGui.QColor(0, 0, 0)
        #color.setNamedColor("gray") #or "#ffffff"
        paint.setPen(QtGui.QColor("gray"))
        paint.setBrush(QtGui.QColor("black"))

        #show CollectingWindowGraph border
        paint.drawRect(0,0,781,30)           

        h0=data.arrayMovementdata[0][0] #first hour
        m0=data.arrayMovementdata[1][0] #first minute
        # 1 minute = 1 px
#        print h0,  m0

        paint.setPen(QtGui.QColor("white"))
#        if(data.zoom==0): step=60
#        else: step=360
        for i in range(60-m0, 781,  60):
            paint.drawLine(i, 30, i, 35)  
            h=(h0+int(i/60)+1) % 24
            paint.drawText(i-15, 60, str(h)+":00")
            paint.drawLine(i, 30, i, 35) 
#            print i,  h




        #draw graph
#        print data.MovementData_ArrayUsage
        for i in range(0,  data.MovementData_ArrayUsage):
            if(data.arrayMovementdata[2][i]==1): #movement
                paint.setPen(QtGui.QColor("yellow"))
                paint.setBrush(QtGui.QColor("yellow"))
                paint.drawLine(i, 1, i, 29)  
                e=i-data.arrayMovementdata[3][i] #elapsed time since last movement in minutes
                if(e>1):
                    if(data.zoom==1):e=e/6
                    
                    if(e>30): color="#009100" #green
                    elif(e>15): color="#005000" #dark green
                    else: color="#6D0000" #dark red 

                    paint.setBrush(QtGui.QColor(color))
                    paint.setPen(QtGui.QColor(color))
                    x0=data.arrayMovementdata[3][i]+1
                    x1=i-1
                    paint.drawRect(x0, 1, x1-x0, 28) 
#                    print x0,  x1,  color
                
#                print i, "==="




def DeleteLogFile():
    LogWindow.DeleteLogFile()




###########################################################################
#  Class for Main Window
###########################################################################
class frmStartWindow(QtGui.QWidget):
    def __init__(self, parent=None):
        QtGui.QWidget.__init__(self, parent)
        self.ui = Ui_StartWindow()
        self.ui.setupUi(self)

        QtCore.QObject.connect(self.ui.bCollecting, QtCore.SIGNAL("clicked()"), ShowCollectingWindow)
        QtCore.QObject.connect(self.ui.bLog, QtCore.SIGNAL("clicked()"), ShowLogWindow)


    def UpdateScreenStart(self):
        self.ui.lblVersion.setText(data.version)
#        self.ui.graphicsView.load(data.configfolder+"SleepAnalyser.png")



###########################################################################
#  Class for Collecting Window
###########################################################################
class frmCollectingWindow(QtGui.QWidget):
    def __init__(self, parent=None):
        QtGui.QWidget.__init__(self, parent)
        self.ui = Ui_CollectingWindow()
        self.ui.setupUi(self)

    def UpdateScreen(self):
            self.ui.lblXacc.setText(str(data.arraySensorData[1][data.SensorData_ArrayIndex]))
            self.ui.lblYacc.setText(str(data.arraySensorData[2][data.SensorData_ArrayIndex]))
            self.ui.lblSamples_Taken.setText(str(data.values_total))

            t=time.mktime(time.localtime())
            time_difference=t-data.StartTimeSec
            t=strftime("%H:%M:%S", time.localtime(time_difference))
            self.ui.lblElapsedTime.setText(t)
            self.ui.lblTrigger.setText(str(data.trigger))
            

    def UpdateScreenStart(self):
        self.ui.lblLogfile.setText(str(data.logfilename))
        t= t=strftime("%d. %b %Y %H:%M:%S", data.StartTime)
        self.ui.lblStarttime.setText(t)


    def closeEvent(self, event):
#        print "Close CollectingWindow"
        StopMeasurement()
        CollectingWindow.close()
        StartWindow.show()

   
   


###########################################################################
# Class for Log Window
###########################################################################
class frmLogWindow(QtGui.QWidget):
    def __init__(self, parent=None):
        QtGui.QWidget.__init__(self, parent)
        self.ui = Ui_LogWindow()
        self.ui.setupUi(self)
        
        QtCore.QObject.connect(self.ui.bRaiseTrigger, QtCore.SIGNAL("clicked()"), RaiseTrigger)
        QtCore.QObject.connect(self.ui.bLowerTrigger, QtCore.SIGNAL("clicked()"), LowerTrigger)
        QtCore.QObject.connect(self.ui.cZoom, QtCore.SIGNAL("clicked()"), Zoom)
        QtCore.QObject.connect(self.ui.bDelete, QtCore.SIGNAL("clicked()"), DeleteLogFile)


    def UpdateScreen(self):
        self.ui.lblLogfile.setText(data.logfilename)
        x=data.arrayMovementdata[1][0]
#        if(x<10): m="0"+str(x)
#        else: m=str(x)
#        self.ui.lblStarttime.setText(str(data.arrayMovementdata[0][0])+":"+m)
        self.ui.lblStarttime.setText(data.arraySensorData[0][0])
#        m=data.arraySensorData[1][data.SensorData_ArrayIndex]
        self.ui.lblStoptime.setText(data.arraySensorData[0][data.SensorData_ArrayIndex-1])
        self.ui.lblTrigger.setText(str(data.trigger))


    def DeleteLogFile(self):
        reply = QtGui.QMessageBox.question(self, 'Delete Logfile', "Are you sure you want to delete this Logfile?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
        if reply == QtGui.QMessageBox.Yes:
            print "Delete logfile: "+data.logfilename
            os.remove(data.logfilename)    
            StartWindow.show()
            LogWindow.hide()



    def closeEvent(self, event):
#        print "Close LogWindow"
        LogWindow.close()
        StartWindow.show()















###########################################################################
# Class for drawing the CollectingWindowGraph
###########################################################################
class CollectingWindowCanvas(QtGui.QWidget):

    def __init__(self, parent=None):
        QtGui.QWidget.__init__(self, CollectingWindow)    
        self.setGeometry(9, 300, 782, 100)
    
    def paintEvent(self, event):
        showGraph(self)



    
    
###########################################################################
# Class for drawing the LogWindowGraph
###########################################################################
class LogWindowCanvas(QtGui.QWidget):

    def __init__(self, parent=None):
        QtGui.QWidget.__init__(self, LogWindow)    
        self.setGeometry(9, 100, 782, 100)
    
    def paintEvent(self, event):
        showGraph(self)
    
    
    

###########################################################################
# Now we can start it.
main()

==> sleepanalyser_1.0-10.tar.gz: sleepanalyser-1.0/src/opt/SleepAnalyser/main.py <==
#!/usr/bin/env python
###########################################################################
# Name: 	         SleepAnalyser
# Description:	 Analyses your movement during your sleep
# Copyright:     George Ruinelli, george@ruinelli.ch
# Last change:  (See file "version")
# Licence:         GPL
###########################################################################

import sys
import os
import random
import time
from time import strftime
import math
import array
import string

from PyQt4.QtCore import * 
from PyQt4.QtGui import * 

import ConfigParser
import os, os.path

import data

from myFunctions import *
from myFunctions2 import *

from Ui_StartWindow import *
from Ui_CollectingWindow import *
from Ui_LogWindow import *
from Ui_NoteWindow import *



  
###########################################################################
# Main function
###########################################################################
def main():
    global app,  StartWindow,  CollectingWindow,  LogWindow ,  NoteWindow
    global config
    global CollectingWindowGraph
   
    try:
        if(sys.argv[1]=="debug"): 
            print "Enable Debug mode"
            data.debug=1
    except:
        data.debug=0

    #if not on the N900, a acceleration sensor has to be simulated
    uname=os.uname()
    if(uname[1]=="Nokia-N900"): data.demo=0	#runs on real N900 hardware
    else: data.demo=1	#runs on other hardware/OS


    if(data.demo==1):
        print "Runs not on a N900 => Use randomizer for acceleration sensor data"
        data.configfolder=data.devconfigfolder
        data.logfolder=data.devlogfolder

    app = QtGui.QApplication(sys.argv)
    
    StartWindow = frmStartWindow()    
    CollectingWindow = frmCollectingWindow()
    LogWindow = frmLogWindow()
    NoteWindow = frmNoteWindow()
    
    StartWindow.show()      
#    ShowLogWindow()

    config=LoadConfig()

    StartWindow.UpdateScreenStart()
    StartWindow.show()

    sys.exit(app.exec_())







###########################################################################
#  Gets called every second,
###########################################################################
def TimerLoop():
    global CollectingWindowGraph

    r=GetSensorData()
    if(r==1):
        WriteIntoLogFile()
        ProcessData()
        CollectingWindowGraph.update() #show CollectingWindowGraph    
    
    CollectingWindow.UpdateScreen()

  
  
  
  
###########################################################################
# Show the collectring window (her ethe data gets visualised during the logging)
###########################################################################
def ShowCollectingWindow():
    CollectingWindow.show()
    StartWindow.hide()
    StartMeasurement()
    
  
###########################################################################
# Show the log window (her ethe data from a file gets visualised)
###########################################################################
def ShowLogWindow():
    global LogWindowGraph
    
    data.logfilename = QFileDialog.getOpenFileName(None,"Open SleepCycle Log File", data.logfolder, "Log Files (*.csv)");
#    data.logfilename = data.logfolder+"atest.csv"
    OpenLogFile()
    ProcessData()
    
    LogWindow.UpdateScreen()

    LogWindow.show()
    StartWindow.hide()
    
    LogWindowGraph = LogWindowCanvas()
    data.Xscale=1 #default zoom level
    LogWindowGraph.show()




############################################################################
## Stretch graph to show more details
############################################################################
def ZoomIn():
    if(data.Xscale==0): return
    LogWindow.ui.bZoomOut.setEnabled(True)
    if(data.Xscale==1): LogWindow.ui.bZoomIn.setEnabled(False)
    else: LogWindow.ui.bZoomIn.setEnabled(True)
    data.Xscale=(data.Xscale-1) % data.arrXscaleLen
    ProcessData()
    LogWindow.update()

def ZoomOut():
    if(data.Xscale==data.arrXscaleLen-1): return
    LogWindow.ui.bZoomIn.setEnabled(True)
    if(data.Xscale==data.arrXscaleLen-2): LogWindow.ui.bZoomOut.setEnabled(False)
    else: LogWindow.ui.bZoomOut.setEnabled(True)
    data.Xscale=(data.Xscale+1) % data.arrXscaleLen
    ProcessData()
    LogWindow.update()





###########################################################################
# Starte the measurement
###########################################################################
def StartMeasurement():
    global CollectingWindowGraph
    global app
    
    StartLogfile()
    
    #init value
    data.sample_index=0
    data.values_total=0
    data.arrDataIndex=0
        
    CollectingWindowGraph = CollectingWindowCanvas()
    data.Xscale=1 #default zoom level
    CollectingWindowGraph.show()
    
    print "Start timers..."
    app.timer_GetData = QtCore.QTimer()
    QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), TimerLoop)        
    app.timer_GetData.start(data.sampling)
    
    CollectingWindow.UpdateScreenStart()
    



###########################################################################
# Stop the measurement
###########################################################################
def StopMeasurement():
    global app
    print "Stop timers..."
    app.timer_GetData.stop()
    StopLogfile()        




###########################################################################
# Raise the trigger in the graph + sleep phases
###########################################################################
def RaiseTrigger():   
    data.trigger=data.trigger+1
    if(data.trigger>100): data.trigger=100
    
    ProcessData()
    LogWindowGraph.update() #show logWindowGraph    
    LogWindow.UpdateScreen()
    
   
   

###########################################################################
# Lower the trigger in the graph + sleep phases
###########################################################################
def LowerTrigger():   
    data.trigger=data.trigger-1
    if(data.trigger<0): data.trigger=0
    
    ProcessData()
    LogWindowGraph.update() #show logWindowGraph    
    LogWindow.UpdateScreen()
   
   
   
   
   
   

###########################################################################
# Show (refreshs) the graph.
# the parameter indcates on which window it will be drawn
###########################################################################
def showGraph(self):
#        print "Show Graph"
        paint = QtGui.QPainter()
        paint.begin(self)

        paint.setFont(QtGui.QFont('Decorative', 12))
        paint.setPen(QtGui.QColor("gray"))
        paint.setBrush(QtGui.QColor("black"))

        #show CollectingWindowGraph border
        paint.drawRect(0,0,781,data.Ysize)           

        Xscale=data.arrXscale[data.Xscale]
        print "Zoom level:",  data.Xscale

        x=data.arrDataIndex/Xscale
        if(x>775): 
            shift=(x-775)*Xscale
            print "Curve too long,  dropping first",  shift,  "values"
        else: shift=0
            
        try:
            t=string.split(data.arrData[0][shift], ":")
            h0=int(t[0])
            m0=int(t[1])
        except:
            h0=int(strftime("%H", time.localtime()))
            m0=int(strftime("%M", time.localtime()))
        # 1 minute = 1 px
        print "Start time of graph:",  h0,  m0

        
        
        
        #draw Xscale
        paint.setPen(QtGui.QColor("white"))
        
        #decade:
        #6 => 60px/h
        #1 => 360px/h
        decade=360/Xscale
        minutestonexthour=60-m0
        offset=minutestonexthour*decade/60
        
        #main lines + text
        for i in range(0, 781+decade,  decade):
            paint.drawLine(i+offset, data.Ysize, i+offset, data.Ysize+10)  
            for k in range(1, 6):
                x=i+offset+k*decade/6-decade
                paint.drawLine(x, data.Ysize, x, data.Ysize+5)  
            h=(h0+int(i/decade)+1) % 24
            paint.drawText(i+offset-20, data.Ysize+30, str(h)+":00") 

        y=(data.Ysize-(data.trigger*data.Yscale))-2
        paint.drawLine(1, y-15, 781, y-15)  









        #draw graph
        lastmove=0
#        print shift,  data.arrDataIndex-data.derivation,  Xscale
        

        for i in range(0,  data.arrDataIndex-shift-data.derivation,  Xscale):
            k=i+shift
            
            #            mov=0
#            peak=0
#            for j in range(0, data.Xscale):
#                if(data.arrData[5][i+j]==1):
#                    mov=mov+1
#                    x=(abs(data.arrData[3][i])+abs(data.arrData[4][i]))
#                    if(x>peak): peak=x
#            print data.arrData[0][i],  i,  "...",  i+j,  "=>",  mov

            
            
            if(1): #one or more movement for this pixel
                peak=abs(data.arrData[3][k])+abs(data.arrData[4][k])
                Y=peak*data.Yscale
                #Draw movement line
                paint.setPen(QtGui.QColor("yellow"))
                paint.setBrush(QtGui.QColor("yellow"))
                paint.drawLine(i/Xscale, data.Ysize-Y-1-15, i/Xscale, data.Ysize-1-15)  
                
                
                #fill space between yellow movement lines
#                if(k>lastmove+1):k
                if(peak>data.trigger):
#                    1=10 sec
                    if((i-lastmove)>30*Xscale): color="#009100" #green
                    elif((i-lastmove)>15*Xscale): color="#005000" #dark green
                    else: color="#6D0000" #dark red 

                    paint.setBrush(QtGui.QColor(color))
                    paint.setPen(QtGui.QColor(color))
                    x0=lastmove/Xscale+1
                    x1=i/Xscale-1
#                    print x0,  "<=>",  x1
                    if(x0<x1):
                        paint.drawRect(x0, data.Ysize-11, x1-x0, 10) 
#                        print "=     Draw field",  x0,  x1,  data.Ysize,  color
                    lastmove=i






###########################################################################
# Delete an existing logfile
###########################################################################
def DeleteLogFile():
    LogWindow.DeleteLogFile()


###########################################################################
# Close the window Notes
###########################################################################
def NotesClose():
    StartWindow.show()
    NoteWindow.close()
    
    
###########################################################################
# Save the notes
###########################################################################
def NotesSave():
    NoteWindow.SaveNotes()
    NotesClose()






















###########################################################################
#  Class for Main Window
###########################################################################
class frmStartWindow(QtGui.QWidget):
    def __init__(self, parent=None):
        QtGui.QWidget.__init__(self, parent)
        self.ui = Ui_StartWindow()
        self.ui.setupUi(self)

        QtCore.QObject.connect(self.ui.bCollecting, QtCore.SIGNAL("clicked()"), ShowCollectingWindow)
        QtCore.QObject.connect(self.ui.bLog, QtCore.SIGNAL("clicked()"), ShowLogWindow)

    def UpdateScreenStart(self):
        app_path=os.path.dirname(__file__)
        file = open(app_path+"/version", 'r')
        data.version = file.readline()
        data.version=data.version[:-1]
        data.build = file.readline()
        self.ui.lblVersion.setText(data.version+"."+data.build)
        self.ui.lblIcon.setPixmap(QtGui.QPixmap(app_path+"/SleepAnalyser.png"))

    def closeEvent(self, event):
        global config
        WriteConfig(config)








###########################################################################
#  Class for Collecting Window
###########################################################################
class frmCollectingWindow(QtGui.QWidget):
    def __init__(self, parent=None):
        QtGui.QWidget.__init__(self, parent)
        self.ui = Ui_CollectingWindow()
        self.ui.setupUi(self)

    def UpdateScreen(self):
#            self.ui.lblXacc.setText(str(data.arrData[1][data.arrDataIndex]))
#            self.ui.lblYacc.setText(str(data.arrData[2][data.arrDataIndex]))
            self.ui.lblSamples_Taken.setText(str(data.values_total))

            t=time.mktime(time.localtime())
            time_difference=t-data.StartTimeSec
            t=strftime("%H:%M:%S", time.localtime(time_difference))
            self.ui.lblElapsedTime.setText(t)
            

    def UpdateScreenStart(self):
        self.ui.lblLogfile.setText(str(data.logfilename))
        t= t=strftime("%d. %b %Y %H:%M:%S", data.StartTime)
        self.ui.lblStarttime.setText(t)
        self.ui.lblSamples_Taken.setText("0")
        self.ui.lblElapsedTime.setText("00:00:00")
        self.ui.lblTrigger.setText(str(data.trigger))
        app_path=os.path.dirname(__file__)
        self.ui.lblIcon.setPixmap(QtGui.QPixmap(app_path+"/SleepAnalyser.png"))


    def closeEvent(self, event):
        StopMeasurement()
        StartWindow.show()
#        NoteWindow.show()
        CollectingWindow.close()

   
   






###########################################################################
# Class for Log Window
###########################################################################
class frmLogWindow(QtGui.QWidget):
    def __init__(self, parent=None):
        QtGui.QWidget.__init__(self, parent)
        self.ui = Ui_LogWindow()
        self.ui.setupUi(self)
        
        QtCore.QObject.connect(self.ui.bRaiseTrigger, QtCore.SIGNAL("clicked()"), RaiseTrigger)
        QtCore.QObject.connect(self.ui.bLowerTrigger, QtCore.SIGNAL("clicked()"), LowerTrigger)
        QtCore.QObject.connect(self.ui.bZoomIn, QtCore.SIGNAL("clicked()"), ZoomIn)
        QtCore.QObject.connect(self.ui.bZoomOut, QtCore.SIGNAL("clicked()"), ZoomOut)
#        QtCore.QObject.connect(self.ui.cZoom, QtCore.SIGNAL("clicked()"), Zoom)
        QtCore.QObject.connect(self.ui.bDelete, QtCore.SIGNAL("clicked()"), DeleteLogFile)


    def UpdateScreen(self):
        self.ui.lblLogfile.setText(data.logfilename)
        self.ui.lblStarttime.setText(str(data.arrData[0][0]))
        self.ui.lblStoptime.setText(str(data.arrData[0][data.arrDataIndex-1]))
        self.ui.lblTrigger.setText(str(data.trigger))


    def DeleteLogFile(self):
        reply = QtGui.QMessageBox.question(self, 'Delete Logfile', "Are you sure you want to delete this Logfile?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
        if reply == QtGui.QMessageBox.Yes:
            print "Delete logfile: "+data.logfilename
            os.remove(data.logfilename)    
            StartWindow.show()
            LogWindow.hide()



    def closeEvent(self, event):
#        self.ui.cZoom.setChecked(False)
#        Zoom()
        config.set('main', 'trigger', str(data.trigger))      
        LogWindow.close()
        StartWindow.show()











###########################################################################
# Class for Log Window
###########################################################################
class frmNoteWindow(QtGui.QWidget):
    def __init__(self, parent=None):
        QtGui.QWidget.__init__(self, parent)
        self.ui = Ui_NoteWindow()
        self.ui.setupUi(self)
        
        QtCore.QObject.connect(self.ui.bClose, QtCore.SIGNAL("clicked()"), NotesClose)
        QtCore.QObject.connect(self.ui.bSave, QtCore.SIGNAL("clicked()"), NotesSave)
        
        
    def SaveNotes(self):
        txt=""
        if(self.ui.cFeedback1.isChecked()==true):
            pass

    def closeEvent(self, event):
        NoteWindow.close()
        StartWindow.show()











###########################################################################
# Class for drawing the CollectingWindowGraph
###########################################################################
class CollectingWindowCanvas(QtGui.QWidget):
    def __init__(self, parent=None):
        QtGui.QWidget.__init__(self, CollectingWindow)    
        self.setGeometry(9, 200, 782, data.Ysize+30)
    
    def paintEvent(self, event):
        showGraph(self)





    
    
###########################################################################
# Class for drawing the LogWindowGraph
###########################################################################
class LogWindowCanvas(QtGui.QWidget):
    def __init__(self, parent=None):
        QtGui.QWidget.__init__(self, LogWindow)    
        self.setGeometry(9, 100, 782, data.Ysize+30)
    
    def paintEvent(self, event):
        showGraph(self)
    
    
    

    
    
    

###########################################################################
# Now we can start it.
main()
